Crate eth_valkyoth_primitives

Crate eth_valkyoth_primitives 

Core no_std Ethereum primitive types used across the eth workspace.

Structs

Address
Fixed-width Ethereum address bytes.
B256
Fixed-width 256-bit hash bytes.
BlockNumber
Ethereum execution-layer block number.
ChainId
Ethereum chain identifier.
Choice
The Choice struct represents a choice for use in conditional assignment.
Gas
Gas quantity.
Nonce
Account transaction nonce.
TransactionType
EIP-2718 transaction envelope type.
UnixTimestamp
Block timestamp as Unix seconds.
Wei
Wei amount encoded as an unsigned 256-bit big-endian integer.

Enums

PrimitiveError
Primitive constructor failures.
PrimitiveRlpError
Primitive RLP bridge failures.