#[non_exhaustive]pub enum PrimitiveError {
NonCanonicalInteger,
IntegerTooLarge,
TransactionTypeTooLarge,
ReservedLegacyType,
UnexpectedCodecError,
}Expand description
Primitive constructor failures.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonCanonicalInteger
Integer bytes were not in shortest-form canonical big-endian encoding.
IntegerTooLarge
Integer bytes exceed the primitive’s fixed-width range.
TransactionTypeTooLarge
Transaction type exceeds the EIP-2718 single-byte typed envelope range.
ReservedLegacyType
Zero is reserved for the legacy transaction domain, not a typed envelope.
UnexpectedCodecError
A codec error unexpected for the selected primitive helper was returned.