Wei

Struct Wei 

pub struct Wei(/* private fields */);
Wei amount encoded as an unsigned 256-bit big-endian integer.

Implementations

Source

impl Wei

pub fn encoded_rlp_len(self) -> Result<usize, PrimitiveRlpError>

Returns the canonical RLP encoded length.

pub fn encode_rlp(self, output: &mut [u8]) -> Result<usize, PrimitiveRlpError>

Canonically encodes this value into output.

Returns the number of bytes written. output is not modified unless this function returns Ok.

pub fn try_from_rlp( input: &[u8], limits: DecodeLimits, ) -> Result<Self, PrimitiveRlpError>

Decodes exactly one canonical RLP U256 integer into Wei.

Source

impl Wei

pub const ZERO: Self

Zero wei.

pub const fn from_be_bytes(bytes: [u8; 32]) -> Self

Creates a wei amount from unsigned 256-bit big-endian bytes.

pub const fn from_u128(value: u128) -> Self

Creates a wei amount from a u128.

pub const fn to_be_bytes(self) -> [u8; 32]

Returns unsigned 256-bit big-endian bytes.

pub fn try_from_canonical_be_slice(bytes: &[u8]) -> Result<Self, PrimitiveError>

Creates a wei amount from a canonical RLP integer payload.

The empty payload represents zero. Non-empty payloads must be shortest-form unsigned big-endian bytes without a leading zero.

pub fn ct_eq(&self, other: &Self) -> Choice

Compares two wei values in constant time.

Wei is usually public, but fixed-width constant-time equality keeps proof and verification paths from accidentally choosing a weaker API.