Core no_std Ethereum primitive types used across the eth workspace.
Structs
- Address
- Fixed-width Ethereum address bytes.
- B256
- Fixed-width 256-bit hash bytes.
- Block
Number - Ethereum execution-layer block number.
- ChainId
- Ethereum chain identifier.
- Choice
- The
Choicestruct represents a choice for use in conditional assignment. - Gas
- Gas quantity.
- Nonce
- Account transaction nonce.
- Transaction
Type - EIP-2718 transaction envelope type.
- Unix
Timestamp - Block timestamp as Unix seconds.
- Wei
- Wei amount encoded as an unsigned 256-bit big-endian integer.
Enums
- Primitive
Error - Primitive constructor failures.
- Primitive
RlpError - Primitive RLP bridge failures.